==> redpesk-cli_3.18.0.orig.tar.gz: redpesk-cli-3.18.0/cmd/connections_constants.go <==
/*
Copyright © 2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage
 Licensees holding valid commercial IoT.bzh licenses may use this file in
 accordance with the commercial license agreement provided with the
 Software or, alternatively, in accordance with the terms contained in
 a written agreement between you and The IoT.bzh Company. For licensing terms
 and conditions see https://www.iot.bzh/terms-conditions. For further
 information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage
 Alternatively, this file may be used under the terms of the GNU General
 Public license version 3. This license is as published by the Free Software
 Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 of this file. Please review the following information to ensure the GNU
 General Public License requirements will be met
 https://www.gnu.org/licenses/gpl-3.0.html.
$RP_END_LICENSE$
*/

package cmd

const (
	// --------------------------------------------------------------
	// Subcommands and their subcommands ----------------------------
	// --------------------------------------------------------------
	// connections command
	connectionsCommand           = "connections"
	connectionsCmdShortDesc      = "Connections commands group"
	localConnectionsCmdShortDesc = "Subcommands group relative to the localbuilder connections"

	connectionsListCmd            = "list"
	connectionsListCmdShortDesc   = "List the available connections to different %s"
	connectionsListCmdLongDesc    = "List the available connections to different %s. These connections need to have been added beforehand."
	connectionsListAnsHeader      = "Alias\t URL\t Token_start\t Admin"
	connectionsListAnsHeaderLocal = "Alias\t IP"
	connectionsListAnsLine0       = "Alias:\t"
	connectionsListAnsLine1       = "Factory URL:\t"
	connectionsListAnsLine1Local  = "Local-builder IP:\t"
	connectionsListAnsLine2       = "Access token:\t"
	connectionsListAnsLine3       = "Admin:\t"
	connectionsListAnsLine4       = "Custom localbuilder URL:\t"
	connectionsListAnsLine5       = "Custom gitpkgs directory:\t"
	connectionsListAnsLine6       = "Custom gitsources directory:\t"

	connectionsGetCmd           = "get <connection-alias>"
	connectionsGetCmdShortUsage = "Get the properties of a connection from its alias"

	connectionsCurrentCmd           = "current"
	connectionsCurrentCmdShortUsage = "Display the current connection used by rp-cli"

	connectionsAddCmd                 = "add <connection-alias>"
	connectionsAddShortDesc           = "Define a new connection"
	connectionsAddLongDesc            = "Define a new connection in the list of %s available. If the alias already exists, the connection is overwritten"
	connectionsAddURLFlag             = "url"
	connectionsAddURLFlagAlias        = "u"
	connectionsAddURLFlagUsage        = "[Mandatory] URL of the Redpesk factory to add"
	connectionsAddIPFlag              = "ip"
	connectionsAddIPFlagAlias         = "i"
	connectionsAddIPFlagUsage         = "[Mandatory] IP of the local-builder to add"
	connectionsAddTokenFlag           = "token"
	connectionsAddTokenFlagAlias      = "t"
	connectionsAddTokenFlagUsage      = "[Mandatory] Access token identifying rp-cli on the Redpesk factory to add"
	connectionsAddLocalBFlag          = "localbuilder-url"
	connectionsAddLocalBFlagAlias     = "l"
	connectionsAddLocalBFlagUsage     = "[Optional] Custom localbuilder URL for this connection (if not set default is used)"
	connectionsAddGitpkgsDirFlag      = "pkgsdir"
	connectionsAddGitpkgsDirFlagAlias = "p"
	connectionsAddGitpkgsDirFlagUsage = "[Optional] Custom \"gitpkgs/\" directory used with localbuilder (if not set default is used)"
	connectionsAddGitsrcsDirFlag      = "sourcesdir"
	connectionsAddGitsrcsDirFlagAlias = "s"
	connectionsAddGitsrcsDirFlagUsage = "[Optional] Custom \"gitsources/\" directory used with localbuilder (if not set default is used)"
	connectionsAddAnsLine0            = "-- Save new connection --"
	connectionsAddAnsLine1            = "Adding the new connection...\t"

	connectionsUpdateCmd            = "update <connection-alias>"
	connectionsUpdateShortDesc      = "Update an existing connection"
	connectionsUpdateURLFlag        = "url"
	connectionsUpdateURLFlagAlias   = "u"
	connectionsUpdateURLFlagUsage   = "[Optional] URL of the Redpesk factory"
	connectionsUpdateIPFlag         = "ip"
	connectionsUpdateIPFlagAlias    = "i"
	connectionsUpdateIPFlagUsage    = "[Optional] IP of the local-builder"
	connectionsUpdateTokenFlag      = "token"
	connectionsUpdateTokenFlagAlias = "t"
	connectionsUpdateTokenFlagUsage = "[Optional] Access token identifying rp-cli on the Redpesk factory"
	connectionsUpdateAnsLine0       = "-- Update connection --"
	connectionsUpdateAnsLine1       = "Updating the '%s' connection...\t"

	connectionsDeleteCmd           = "delete <connection-alias>"
	connectionsDeleteCmdShortUsage = "Delete one connection from the %s connections list"
	connectionsDeleteAnsLine0      = "-- Delete one %s connection --\n"
	connectionsDeleteAnsLine1      = "Deleting the '%s' connection...\t"

	connectionsUseCmd          = "use <connection-alias>"
	connectionsUseCmdShortDesc = "Change the %s connection currently used by rp-cli"
	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Error messages -----------------------------------------------
	// --------------------------------------------------------------
	connectionAliasNotSetMsg   = "no connection alias argument in the command line"
	connectionAliasRequiredMsg = "a connection alias is required for the wanted operation, please provide one"
	connectionAliasNotExistMsg = "no connection has been found with the identifier \"%s\", please provide an existing one"
	connectionTypeUnknownMsg   = "the connection type cannot be deduced from the command \"%s\""
	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Warning messages ---------------------------------------------
	// --------------------------------------------------------------
	// --------------------------------------------------------------
)

==> redpesk-cli_3.18.3.orig.tar.gz: redpesk-cli-3.18.3/cmd/connections_constants.go <==
/*
Copyright © 2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage
 Licensees holding valid commercial IoT.bzh licenses may use this file in
 accordance with the commercial license agreement provided with the
 Software or, alternatively, in accordance with the terms contained in
 a written agreement between you and The IoT.bzh Company. For licensing terms
 and conditions see https://www.iot.bzh/terms-conditions. For further
 information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage
 Alternatively, this file may be used under the terms of the GNU General
 Public license version 3. This license is as published by the Free Software
 Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 of this file. Please review the following information to ensure the GNU
 General Public License requirements will be met
 https://www.gnu.org/licenses/gpl-3.0.html.
$RP_END_LICENSE$
*/

package cmd

const (
	// --------------------------------------------------------------
	// Subcommands and their subcommands ----------------------------
	// --------------------------------------------------------------
	// connections command
	connectionsCommand           = "connections"
	connectionsCmdShortDesc      = "Connections commands group"
	localConnectionsCmdShortDesc = "Subcommands group relative to the localbuilder connections"

	connectionsListCmd            = "list"
	connectionsListCmdShortDesc   = "List the available connections to different %s"
	connectionsListCmdLongDesc    = "List the available connections to different %s. These connections need to have been added beforehand."
	connectionsListAnsHeader      = "Alias\t URL\t Token_start\t Admin"
	connectionsListAnsHeaderLocal = "Alias\t IP\t Build_root_directory"
	connectionsListAnsLine0       = "Alias:\t"
	connectionsListAnsLine1       = "Factory URL:\t"
	connectionsListAnsLine1Local  = "Local-builder IP:\t"
	connectionsListAnsLine2Local  = "Build root directory:\t"
	connectionsListAnsLine2       = "Access token:\t"
	connectionsListAnsLine3       = "Admin:\t"
	connectionsListAnsLine4       = "Custom localbuilder URL:\t"
	connectionsListAnsLine5       = "Custom gitpkgs directory:\t"
	connectionsListAnsLine6       = "Custom gitsources directory:\t"

	connectionsGetCmd           = "get <connection-alias>"
	connectionsGetCmdShortUsage = "Get the properties of a connection from its alias"

	connectionsCurrentCmd           = "current"
	connectionsCurrentCmdShortUsage = "Display the current connection used by rp-cli"

	connectionsAddCmd       = "add <connection-alias>"
	connectionsAddShortDesc = "Define a new connection"
	connectionsAddLongDesc  = "Define a new connection in the list of %s available. If the alias already exists, the connection is overwritten"

	connectionsAddURLFlag      = "url"
	connectionsAddURLFlagAlias = "u"
	connectionsAddURLFlagUsage = "[Mandatory] URL of the Redpesk factory to add"

	connectionsAddIPFlag      = "ip"
	connectionsAddIPFlagAlias = "i"
	connectionsAddIPFlagUsage = "[Mandatory] IP of the local-builder to add"

	connectionsLocalBldRootDirFlag      = "root-dir"
	connectionsLocalBldRootDirFlagAlias = "r"
	connectionsLocalBldRootDirFlagUsage = "[Optional] Custom 'root' directory to use for build inside the localbuilder"

	connectionsAddTokenFlag      = "token"
	connectionsAddTokenFlagAlias = "t"
	connectionsAddTokenFlagUsage = "[Mandatory] Access token identifying rp-cli on the Redpesk factory to add"

	connectionsAddLocalBFlag      = "localbuilder-url"
	connectionsAddLocalBFlagAlias = "l"
	connectionsAddLocalBFlagUsage = "[Optional] Custom localbuilder URL for this connection (if not set default is used)"

	connectionsAddGitpkgsDirFlag      = "pkgsdir"
	connectionsAddGitpkgsDirFlagAlias = "p"
	connectionsAddGitpkgsDirFlagUsage = "[Optional] Custom \"gitpkgs/\" directory used with localbuilder (if not set default is used)"

	connectionsAddGitsrcsDirFlag      = "sourcesdir"
	connectionsAddGitsrcsDirFlagAlias = "s"
	connectionsAddGitsrcsDirFlagUsage = "[Optional] Custom \"gitsources/\" directory used with localbuilder (if not set default is used)"

	connectionsAddAnsLine0 = "-- Save new connection --"
	connectionsAddAnsLine1 = "Adding the new connection...\t"

	connectionsUpdateCmd            = "update <connection-alias>"
	connectionsUpdateShortDesc      = "Update an existing connection"
	connectionsUpdateURLFlag        = "url"
	connectionsUpdateURLFlagAlias   = "u"
	connectionsUpdateURLFlagUsage   = "[Optional] URL of the Redpesk factory"
	connectionsUpdateIPFlag         = "ip"
	connectionsUpdateIPFlagAlias    = "i"
	connectionsUpdateIPFlagUsage    = "[Optional] IP of the local-builder"
	connectionsUpdateTokenFlag      = "token"
	connectionsUpdateTokenFlagAlias = "t"
	connectionsUpdateTokenFlagUsage = "[Optional] Access token identifying rp-cli on the Redpesk factory"
	connectionsUpdateAnsLine0       = "-- Update connection --"
	connectionsUpdateAnsLine1       = "Updating the '%s' connection...\t"

	connectionsDeleteCmd           = "delete <connection-alias>"
	connectionsDeleteCmdShortUsage = "Delete one connection from the %s connections list"
	connectionsDeleteAnsLine0      = "-- Delete one %s connection --\n"
	connectionsDeleteAnsLine1      = "Deleting the '%s' connection...\t"

	connectionsUseCmd          = "use <connection-alias>"
	connectionsUseCmdShortDesc = "Change the %s connection currently used by rp-cli"
	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Error messages -----------------------------------------------
	// --------------------------------------------------------------
	connectionAliasNotSetMsg   = "no connection alias argument in the command line"
	connectionAliasRequiredMsg = "a connection alias is required for the wanted operation, please provide one"
	connectionAliasNotExistMsg = "no connection has been found with the identifier \"%s\", please provide an existing one"
	connectionTypeUnknownMsg   = "the connection type cannot be deduced from the command \"%s\""
	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Warning messages ---------------------------------------------
	// --------------------------------------------------------------
	// --------------------------------------------------------------
)
